@@ -1,61 +1,76 @@
-# ABSTRACT: YAML Framework
+# ABSTRACT: YAML 1.2 Processor
 use strict;
 use warnings;
 package YAML::PP;
 
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 use YAML::PP::Schema;
 use YAML::PP::Schema::JSON;
 use YAML::PP::Loader;
 use YAML::PP::Dumper;
 use Scalar::Util qw/ blessed /;
+use Carp qw/ croak /;
 
 use base 'Exporter';
 our @EXPORT_OK = qw/ Load LoadFile Dump DumpFile /;
 
+my %YAML_VERSIONS = ('1.1' => 1, '1.2' => 1);
+
+
 sub new {
     my ($class, %args) = @_;
 
     my $bool = delete $args{boolean};
     $bool = 'perl' unless defined $bool;
-    my $schemas = delete $args{schema} || ['JSON'];
+    my $schemas = delete $args{schema} || ['+'];
     my $cyclic_refs = delete $args{cyclic_refs} || 'allow';
     my $indent = delete $args{indent};
     my $writer = delete $args{writer};
     my $header = delete $args{header};
     my $footer = delete $args{footer};
+    my $yaml_version = $class->_arg_yaml_version(delete $args{yaml_version});
+    my $default_yaml_version = $yaml_version->[0];
+    my $version_directive = delete $args{version_directive};
     my $parser = delete $args{parser};
     my $emitter = delete $args{emitter} || {
         indent => $indent,
         writer => $writer,
     };
 
-    my $schema;
-    if (blessed($schemas) and $schemas->isa('YAML::PP::Schema')) {
-        $schema = $schemas;
-    }
-    else {
-        $schema = YAML::PP::Schema->new(
-            boolean => $bool,
-        );
-        $schema->load_subschemas(@$schemas);
+    my %schemas;
+    for my $v (@$yaml_version) {
+        my $schema;
+        if (blessed($schemas) and $schemas->isa('YAML::PP::Schema')) {
+            $schema = $schemas;
+        }
+        else {
+            $schema = YAML::PP::Schema->new(
+                boolean => $bool,
+                yaml_version => $v,
+            );
+            $schema->load_subschemas(@$schemas);
+        }
+        $schemas{ $v } = $schema;
     }
+    my $default_schema = $schemas{ $default_yaml_version };
 
     my $loader = YAML::PP::Loader->new(
-        schema => $schema,
+        schemas => \%schemas,
         cyclic_refs => $cyclic_refs,
         parser => $parser,
+        default_yaml_version => $default_yaml_version,
     );
     my $dumper = YAML::PP::Dumper->new(
-        schema => $schema,
+        schema => $default_schema,
         emitter => $emitter,
         header => $header,
         footer => $footer,
+        version_directive => $version_directive,
     );
 
     my $self = bless {
-        schema => $schema,
+        schema => \%schemas,
         loader => $loader,
         dumper => $dumper,
     }, $class;
@@ -72,6 +87,25 @@ sub clone {
     return bless $clone, ref $self;
 }
 
+sub _arg_yaml_version {
+    my ($class, $version) = @_;
+    my @versions = ('1.2');
+    if (defined $version) {
+        @versions = ();
+        if (not ref $version) {
+            $version = [$version];
+        }
+        for my $v (@$version) {
+            unless ($YAML_VERSIONS{ $v }) {
+                croak "YAML Version '$v' not supported";
+            }
+            push @versions, $v;
+        }
+    }
+    return \@versions;
+}
+
+
 sub loader {
     if (@_ > 1) {
         $_[0]->{loader} = $_[1]
@@ -87,8 +121,8 @@ sub dumper {
 }
 
 sub schema {
-    if (@_ > 1) { $_[0]->{schema} = $_[1] }
-    return $_[0]->{schema};
+    if (@_ > 1) { $_[0]->{schema}->{'1.2'} = $_[1] }
+    return $_[0]->{schema}->{'1.2'};
 }
 
 sub default_schema {
@@ -160,7 +194,7 @@ YAML::PP - YAML 1.2 processor
 
 =head1 SYNOPSIS
 
-WARNING: This is not yet stable.
+WARNING: Most of the inner API is not stable yet.
 
 Here are a few examples of the basic load and dump methods:
 
@@ -206,7 +240,7 @@ Here are a few examples of the basic load and dump methods:
     DumpFile($filename, @documents);
     DumpFile($filenhandle @documents);
 
-    my $ypp = YAML::PP->new(schema => [qw/ JSON Perl /]);
+    my $ypp = YAML::PP->new(schema => [qw/ + Perl /]);
     my $yaml = $yp->dump_string($data_with_perl_objects);
 
 
@@ -231,9 +265,10 @@ Some utility scripts, mostly useful for debugging:
 
 =head1 DESCRIPTION
 
-YAML::PP is a modern, modular YAML processor.
+YAML::PP is a modular YAML processor.
 
 It aims to support C<YAML 1.2> and C<YAML 1.1>. See L<http://yaml.org/>.
+Some (rare) syntax elements are not yet supported and documented below.
 
 YAML is a serialization language. The YAML input is called "YAML Stream".
 A stream consists of one or more "Documents", separated by a line with a
@@ -560,20 +595,119 @@ The layout is like libyaml output:
     
     # Die when detecting cyclic references
     my $ypp = YAML::PP->new( cyclic_refs => 'fatal' );
-    # Other values:
-    # warn   - Just warn about them and replace with undef
-    # ignore - replace with undef
-    # allow  - Default
     
     my $ypp = YAML::PP->new(
         boolean => 'JSON::PP',
-        schema => ['JSON'],
+        schema => ['Core'],
         cyclic_refs => 'fatal',
-        indent => 4, # use 4 spaces for dumping indentation
-        header => 1, # default 1; print document header ---
-        footer => 1, # default 0; print document footer ...
+        indent => 4,
+        header => 1,
+        footer => 1,
+        version_directive => 1,
     );
 
+Options:
+
+=over
+
+=item boolean
+
+Values: C<perl> (currently default), C<JSON::PP>, C<boolean>
+
+=item schema
+
+Default: C<['Core']>
+
+Array reference. Here you can define what schema to use.
+Supported standard Schemas are: C<Failsafe>, C<JSON>, C<Core>, C<YAML1_1>.
+
+To get an overview how the different Schemas behave, see
+L<https://perlpunk.github.io/YAML-PP-p5/schemas.html>
+
+Additionally you can add further schemas, for example C<Merge>.
+
+=item cyclic_refs
+
+Default: 'allow' but will be switched to fatal in the future for safety!
+
+Defines what to do when a cyclic reference is detected when loading.
+
+    # fatal  - die
+    # warn   - Just warn about them and replace with undef
+    # ignore - replace with undef
+    # allow  - Default
+
+=item indent
+
+Default: 2
+
+Use that many spaces for indenting
+
+=item header
+
+Default: 1
+
+Print document heaader C<--->
+
+=item footer
+
+Default: 0
+
+Print document footer C<...>
+
+=item yaml_version
+
+Default: C<1.2>
+
+Note that in this case, a directive C<%YAML 1.1> will basically be ignored
+and everything loaded with the C<1.2 Core> Schema.
+
+If you want to support both YAML 1.1 and 1.2, you have to specify that, and the
+schema (C<Core> or C<YAML1_1>) will be chosen automatically.
+
+    my $yp = YAML::PP->new(
+        yaml_version => ['1.2', '1.1'],
+    );
+
+This is the same as
+
+    my $yp = YAML::PP->new(
+        schema => ['+'],
+        yaml_version => ['1.2', '1.1'],
+    );
+
+because the C<+> stands for the default schema per version.
+
+When loading, and there is no C<%YAML> directive, C<1.2> will be considered
+as default, and the C<Core> schema will be used.
+
+If there is a C<%YAML 1.1> directive, the C<YAML1_1> schema will be used.
+
+Of course, you can also make C<1.1> the default:
+
+    my $yp = YAML::PP->new(
+        yaml_version => ['1.1', '1.2'],
+    );
+
+
+You can also specify C<1.1> only:
+
+    my $yp = YAML::PP->new(
+        yaml_version => ['1.1'],
+    );
+
+In this case also documents with C<%YAML 1.2> will be loaded with the C<YAML1_1>
+schema.
+
+=item version_directive
+
+Default: 0
+
+Print Version Directive C<%YAML 1.2> (or C<%YAML 1.1>) on top of each YAML
+document. It will use the first version specified in the C<yaml_version> option.
+
+=back
+
 =item load_string
 
     my $doc = $ypp->load_string("foo: bar");
@@ -582,7 +716,7 @@ The layout is like libyaml output:
 Input should be Unicode characters.
 
 So if you read from a file, you should decode it, for example with
-C<Encode::decode_utf8($bytes)>.
+C<Encode::decode()>.
 
 Note that in scalar context, C<load_string> and C<load_file> return the first
 document (like L<YAML::Syck>), while L<YAML> and L<YAML::XS> return the
@@ -602,12 +736,11 @@ Strings will be loaded as unicode characters.
     my $yaml = $ypp->dump_string(@docs);
 
 Input strings should be Unicode characters.
-C<utf8::upgrade>.
 
 Output will return Unicode characters.
 
 So if you want to write that to a file (or pass to YAML::XS, for example),
-you typically encode it via C<Encode::encode_utf8($yaml)>.
+you typically encode it via C<Encode::encode()>.
 
 =item dump_file
 
