@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Emitter;
 
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 use Data::Dumper;
 
 use YAML::PP::Common qw/
@@ -49,6 +49,7 @@ sub init {
     $self->set_tagmap({
         'tag:yaml.org,2002:' => '!!',
     });
+    $self->{open_ended} = 0;
     $self->writer->init;
 }
 
@@ -143,6 +144,7 @@ sub mapping_start_event {
     }
     push @{ $stack }, $new_info;
     $last->{index}++;
+    $self->{open_ended} = 0;
 }
 
 sub mapping_end_event {
@@ -260,6 +262,7 @@ sub sequence_start_event {
         $new_info->{type} = 'SEQ';
     }
     push @{ $stack }, $new_info;
+    $self->{open_ended} = 0;
 }
 
 sub sequence_end_event {
@@ -442,7 +445,10 @@ sub scalar_event {
         elsif ($forbidden_first{ $first }) {
             $style = YAML_SINGLE_QUOTED_SCALAR_STYLE;
         }
-        elsif (substr($value, 0, 2) =~ m/^([:?-] )/) {
+        elsif (substr($value, 0, 3) =~ m/^---/) {
+            $style = YAML_SINGLE_QUOTED_SCALAR_STYLE;
+        }
+        elsif (substr($value, 0, 2) =~ m/^(?:[:?-] )/) {
             $style = YAML_SINGLE_QUOTED_SCALAR_STYLE;
         }
         elsif ($value =~ m/: /) {
@@ -463,6 +469,7 @@ sub scalar_event {
         }
     }
 
+    my $open_ended = 0;
     if ($style eq YAML_PLAIN_SCALAR_STYLE) {
         if ($forbidden_first_plus_space{ $first }) {
             if (length ($value) == 1 or substr($value, 1, 1) =~ m/^\s/) {
@@ -503,6 +510,7 @@ sub scalar_event {
         }
         elsif ($value =~ m/(\n|\A)\n\z/) {
             $indicators .= '+';
+            $open_ended = 1;
         }
         $value =~ s/^(?=.)/$indent  /gm;
         $value = "|$indicators\n$value";
@@ -618,6 +626,7 @@ sub scalar_event {
     }
     $last->{column} = $column;
     $self->writer->write($yaml);
+    $self->{open_ended} = $open_ended;
 }
 
 sub alias_event {
@@ -675,6 +684,7 @@ sub alias_event {
         $column = substr($yaml, -1) eq "\n" ? 0 : 1;
     }
     $last->{column} = $column;
+    $self->{open_ended} = 0;
 }
 
 sub document_start_event {
@@ -682,9 +692,16 @@ sub document_start_event {
     my ($self, $info) = @_;
     my $newline = 0;
     my $column = 0;
-    if ($info->{implicit}) {
+    my $implicit = $info->{implicit};
+    if ($info->{version_directive}) {
+        if ($self->{open_ended}) {
+            $self->writer->write("...\n");
+        }
+        $self->writer->write("%YAML $info->{version_directive}\n");
+        $self->{open_ended} = 0;
+        $implicit = 0; # we need ---
     }
-    else {
+    unless ($implicit) {
         $newline = 1;
         $self->writer->write("---");
         $column = 1;
@@ -701,8 +718,12 @@ sub document_end_event {
     DEBUG and warn __PACKAGE__.':'.__LINE__.": +++ document_end_event\n";
     my ($self, $info) = @_;
     $self->set_event_stack([]);
-    unless ($info->{implicit}) {
+    if ($self->{open_ended} or not $info->{implicit}) {
         $self->writer->write("...\n");
+        $self->{open_ended} = 0;
+    }
+    else {
+        $self->{open_ended} = 1;
     }
 }
 
